@@ -1,4 +1,4 @@
-use super::event::{Event, occurance::EventOccurance};
+use super::event::{Event, occurrence::EventOccurrence};
 use chrono::{Date, Utc};
 
 #[derive(Debug, Default)]
@@ -16,10 +16,10 @@ impl Calendar {
         self
     }
 
-    pub fn day(&self, date: Date<Utc>) -> Vec<EventOccurance> {
+    pub fn day(&self, date: Date<Utc>) -> Vec<EventOccurrence> {
         self.events
             .iter()
-            .filter_map(|event| event.get_occurence_at(date))
+            .filter_map(|event| event.get_occurrence_at(date))
             .collect()
     }
 }
